
------------------------------------------------------
--	BEGIN Prevent skipped releases
------------------------------------------------------

	USE [ECMPS_AUX]
	GO
	DECLARE @LAST_RELEASE_DATE DATETIME = '12/08/2021',
			@LAST_VERSION VARCHAR(25) = '2021 Q4',
			@DB_AT_RELEASE_DATE DATETIME,
			@DB_AT_VERSION VARCHAR(25)
		
	SELECT @DB_AT_VERSION=REVISION, @DB_AT_RELEASE_DATE=RELEASE_DATE 
	FROM ECMPS_AUX.dbo.ECMPS_VERSION_LOG 
	WHERE IS_CURRENT_FLG ='Y'

	IF(DATEDIFF(dd, @DB_AT_RELEASE_DATE, @LAST_RELEASE_DATE) <> 0 OR @DB_AT_VERSION<>@LAST_VERSION)
	BEGIN
		PRINT 'UPDATE FAILED: You are not at the correct release to apply this update.' + CHAR(13)
			+ 'This upgrade is for Version ' + @LAST_VERSION + ', dated ' + CONVERT(VARCHAR(10), @LAST_RELEASE_DATE, 101) +'.' + CHAR(13)
			+ 'Your database is at Version ' + @DB_AT_VERSION +', dated ' + CONVERT(VARCHAR(10), @DB_AT_RELEASE_DATE, 101)+ '.' + CHAR(13) + 
			'Please visit http://ecmps.camdsupport.com/downloads_shared_update.shtml to get previous update(s).'

		SET NOEXEC ON
	END

------------------------------------------------------
--	END Prevent skipped releases
------------------------------------------------------


PRINT 'Clean up the workspace tables'
-- Clean up the workspace tables
EXECUTE ECMPS_WS.Client.TruncateWorkspaceTables NULL, NULL
GO 


------------------------------------------------------
--	ECMPS STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS
GO 

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO

SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL Serializable
GO
BEGIN TRANSACTION
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO
PRINT N'Refreshing [dbo].[VW_MONITOR_LOCATION]'
GO
IF OBJECT_ID(N'[dbo].[VW_MONITOR_LOCATION]', 'V') IS NOT NULL
EXEC sp_refreshview N'[dbo].[VW_MONITOR_LOCATION]'
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO
PRINT N'Altering [dbo].[VW_MONITOR_SYSTEM_COMPONENT]'
GO
IF OBJECT_ID(N'[dbo].[VW_MONITOR_SYSTEM_COMPONENT]', 'V') IS NOT NULL
EXEC sp_executesql N'
ALTER VIEW [dbo].[VW_MONITOR_SYSTEM_COMPONENT]
AS
	SELECT	dbo.MONITOR_SYSTEM_COMPONENT.MON_SYS_COMP_ID, dbo.VW_MONITOR_LOCATION.MON_LOC_ID, 
			dbo.VW_MONITOR_LOCATION.ORIS_CODE, dbo.VW_MONITOR_LOCATION.LOCATION_IDENTIFIER, dbo.VW_MONITOR_LOCATION.FAC_ID, 
			dbo.MONITOR_SYSTEM_COMPONENT.MON_SYS_ID, dbo.MONITOR_SYSTEM_COMPONENT.COMPONENT_ID, 
			dbo.MONITOR_SYSTEM_COMPONENT.BEGIN_DATE, dbo.MONITOR_SYSTEM_COMPONENT.BEGIN_HOUR, 
			dbo.MONITOR_SYSTEM_COMPONENT.END_DATE, dbo.MONITOR_SYSTEM_COMPONENT.END_HOUR, dbo.COMPONENT.COMPONENT_TYPE_CD, 
			dbo.COMPONENT.ACQ_CD, dbo.COMPONENT.BASIS_CD, dbo.MONITOR_SYSTEM.BEGIN_DATE AS SYSTEM_BEGIN_DATE, 
			dbo.MONITOR_SYSTEM.BEGIN_HOUR AS SYSTEM_BEGIN_HOUR, dbo.MONITOR_SYSTEM.END_DATE AS SYSTEM_END_DATE, 
			dbo.MONITOR_SYSTEM.END_HOUR AS SYSTEM_END_HOUR, dbo.MONITOR_SYSTEM.SYSTEM_IDENTIFIER, 
			dbo.COMPONENT.COMPONENT_IDENTIFIER,
			dateadd(hour, dbo.MONITOR_SYSTEM_COMPONENT.BEGIN_HOUR, dbo.MONITOR_SYSTEM_COMPONENT.BEGIN_DATE ) as BEGIN_DATEHOUR,
			dateadd(hour, dbo.MONITOR_SYSTEM_COMPONENT.END_HOUR, dbo.MONITOR_SYSTEM_COMPONENT.END_DATE ) as END_DATEHOUR,
			dateadd(hour, dbo.MONITOR_SYSTEM.BEGIN_HOUR, dbo.MONITOR_SYSTEM.BEGIN_DATE ) as SYSTEM_BEGIN_DATEHOUR,
			dateadd(hour, dbo.MONITOR_SYSTEM.END_HOUR, dbo.MONITOR_SYSTEM.END_DATE ) as SYSTEM_END_DATEHOUR
	FROM dbo.MONITOR_SYSTEM_COMPONENT 
		INNER JOIN dbo.COMPONENT ON dbo.MONITOR_SYSTEM_COMPONENT.COMPONENT_ID = dbo.COMPONENT.COMPONENT_ID 
		INNER JOIN dbo.MONITOR_SYSTEM ON dbo.MONITOR_SYSTEM_COMPONENT.MON_SYS_ID = dbo.MONITOR_SYSTEM.MON_SYS_ID 
		INNER JOIN dbo.VW_MONITOR_LOCATION ON dbo.MONITOR_SYSTEM.MON_LOC_ID = dbo.VW_MONITOR_LOCATION.MON_LOC_ID
'
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO
PRINT N'Altering [dbo].[VW_QA_TEST_SUMMARY_LINE]'
GO
IF OBJECT_ID(N'[dbo].[VW_QA_TEST_SUMMARY_LINE]', 'V') IS NOT NULL
EXEC sp_executesql N'
ALTER VIEW [dbo].[VW_QA_TEST_SUMMARY_LINE]
AS
SELECT	ts.TEST_SUM_ID, ts.MON_LOC_ID, ts.TEST_TYPE_CD, ts.COMPONENT_ID, ts.TEST_NUM, 
			ts.GP_IND, ts.TEST_REASON_CD, ts.TEST_RESULT_CD, 
			ts.BEGIN_DATE, ts.BEGIN_HOUR, ts.BEGIN_MIN, 
			ts.END_DATE, ts.END_HOUR, ts.END_MIN, 
			ts.SPAN_SCALE_CD, ts.TEST_COMMENT, 
			ts.LAST_UPDATED, ts.UPDATED_STATUS_FLG, ts.NEEDS_EVAL_FLG, ts.CHK_SESSION_ID,
			ts.USERID, ts.ADD_DATE, ts.UPDATE_DATE, 
			ml.FAC_ID, isnull(ml.STACK_NAME, ml.UNITID) AS LOCATION_IDENTIFIER,
			c.COMPONENT_TYPE_CD, c.COMPONENT_IDENTIFIER, c.ACQ_CD, c.HG_CONVERTER_IND,
            dateadd( hour, ts.BEGIN_HOUR, ts.BEGIN_DATE ) as BEGIN_DATEHOUR,
            dateadd( hour, ts.END_HOUR, ts.END_DATE ) as END_DATEHOUR
			
	FROM dbo.TEST_SUMMARY ts 
		LEFT OUTER JOIN dbo.VW_MONITOR_LOCATION ml ON ts.MON_LOC_ID = ml.MON_LOC_ID 
		LEFT OUTER JOIN dbo.COMPONENT c ON ts.COMPONENT_ID = c.COMPONENT_ID
	WHERE TEST_TYPE_CD IN (''LINE'',''HGLINE'',''HGSI3'')
'
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO
PRINT N'Refreshing [dbo].[VW_SYSTEM_ANALYZER_RANGE]'
GO
IF OBJECT_ID(N'[dbo].[VW_SYSTEM_ANALYZER_RANGE]', 'V') IS NOT NULL
EXEC sp_refreshview N'[dbo].[VW_SYSTEM_ANALYZER_RANGE]'
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO
COMMIT TRANSACTION
GO
IF @@ERROR <> 0 SET NOEXEC ON
GO

------------------------------------------------------
--	ECMPS STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_WS STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS_WS
GO 

------------------------------------------------------
--	ECMPS_WS STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_AUX STRUCTURE SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO 

------------------------------------------------------
--	ECMPS_AUX STRUCTURE SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS DATA SQL (BEGIN)
------------------------------------------------------

USE ECMPS
GO

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS, NOCOUNT ON
GO
SET DATEFORMAT YMD
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION

PRINT(N'Update rows in [MatsTransition].[TEST_METHOD_CODE]')
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=41000 WHERE [TEST_METHOD_CD] = '041'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=100 WHERE [TEST_METHOD_CD] = '1'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=1900 WHERE [TEST_METHOD_CD] = '19'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=200 WHERE [TEST_METHOD_CD] = '2'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=2600 WHERE [TEST_METHOD_CD] = '26'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=2601 WHERE [TEST_METHOD_CD] = '26A'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=2900 WHERE [TEST_METHOD_CD] = '29'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=201 WHERE [TEST_METHOD_CD] = '2A'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=203 WHERE [TEST_METHOD_CD] = '2C'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=206 WHERE [TEST_METHOD_CD] = '2F'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=207 WHERE [TEST_METHOD_CD] = '2G'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=208 WHERE [TEST_METHOD_CD] = '2H'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=3002 WHERE [TEST_METHOD_CD] = '30B'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=32000 WHERE [TEST_METHOD_CD] = '320'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=301 WHERE [TEST_METHOD_CD] = '3A'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=302 WHERE [TEST_METHOD_CD] = '3B'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=400 WHERE [TEST_METHOD_CD] = '4'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=500 WHERE [TEST_METHOD_CD] = '5'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=502 WHERE [TEST_METHOD_CD] = '5B'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=504 WHERE [TEST_METHOD_CD] = '5D'
UPDATE [MatsTransition].[TEST_METHOD_CODE] SET [DISPLAY_ORD]=603 WHERE [TEST_METHOD_CD] = '6C'
PRINT(N'Operation applied to 21 rows out of 21')

PRINT(N'Add row to [MatsTransition].[REPORT_TYPE_CODE]')
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[REPORT_TYPE_CODE] WHERE [REPORT_TYPE_CD] = 'PS11')
	INSERT INTO [MatsTransition].[REPORT_TYPE_CODE] ([REPORT_TYPE_CD], [REPORT_TYPE_DESCRIPTION], [ERT_REPORT_TYPE_CD], [REQUIRES_POLLUTANT_IND]) VALUES ('PS11', 'PM CEMS PS-11 Correlation Test', 'MATS_PS11', 1)

PRINT(N'Add rows to [MatsTransition].[TEST_METHOD_CODE]')
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_CODE] WHERE [TEST_METHOD_CD] = '17')
	INSERT INTO [MatsTransition].[TEST_METHOD_CODE] ([TEST_METHOD_CD], [TEST_METHOD_DESCRIPTION], [DISPLAY_ORD]) VALUES ('17', 'Method 17', 1700)
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_CODE] WHERE [TEST_METHOD_CD] = '3')
	INSERT INTO [MatsTransition].[TEST_METHOD_CODE] ([TEST_METHOD_CD], [TEST_METHOD_DESCRIPTION], [DISPLAY_ORD]) VALUES ('3', 'Method 3', 300)
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_CODE] WHERE [TEST_METHOD_CD] = '5I')
	INSERT INTO [MatsTransition].[TEST_METHOD_CODE] ([TEST_METHOD_CD], [TEST_METHOD_DESCRIPTION], [DISPLAY_ORD]) VALUES ('5I', 'Method 5I', 509)
PRINT(N'Operation applied to 3 rows out of 3')

PRINT(N'Add row to [MatsTransition].[REPORT_TYPE_TO_POLLUTANT_CROSSCHECK]')
SET IDENTITY_INSERT [MatsTransition].[REPORT_TYPE_TO_POLLUTANT_CROSSCHECK] ON
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[REPORT_TYPE_TO_POLLUTANT_CROSSCHECK] WHERE [REPORT_TYPE_TO_POLLUTANT_ID] = 39)
	INSERT INTO [MatsTransition].[REPORT_TYPE_TO_POLLUTANT_CROSSCHECK] ([REPORT_TYPE_TO_POLLUTANT_ID], [REPORT_TYPE_CD], [POLLUTANT_CD]) VALUES (39, 'PS11', 'FPM')
SET IDENTITY_INSERT [MatsTransition].[REPORT_TYPE_TO_POLLUTANT_CROSSCHECK] OFF

PRINT(N'Add rows to [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK]')
SET IDENTITY_INSERT [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] ON
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] WHERE [TEST_METHOD_TO_POLLUTANT_ID] = 38)
	INSERT INTO [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] ([TEST_METHOD_TO_POLLUTANT_ID], [TEST_METHOD_CD], [POLLUTANT_CD], [REQUIRED_IND]) VALUES (38, '3', NULL, 0)
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] WHERE [TEST_METHOD_TO_POLLUTANT_ID] = 39)
	INSERT INTO [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] ([TEST_METHOD_TO_POLLUTANT_ID], [TEST_METHOD_CD], [POLLUTANT_CD], [REQUIRED_IND]) VALUES (39, '5I', 'FPM', 1)
IF NOT EXISTS( SELECT 1 FROM [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] WHERE [TEST_METHOD_TO_POLLUTANT_ID] = 40)
	INSERT INTO [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] ([TEST_METHOD_TO_POLLUTANT_ID], [TEST_METHOD_CD], [POLLUTANT_CD], [REQUIRED_IND]) VALUES (40, '17', 'FPM', 1)
SET IDENTITY_INSERT [MatsTransition].[TEST_METHOD_TO_POLLUTANT_CROSSCHECK] OFF
PRINT(N'Operation applied to 3 rows out of 3')
COMMIT TRANSACTION
GO

------------------------------------------------------
--	ECMPS DATA SQL (END)
------------------------------------------------------


------------------------------------------------------
--	ECMPS_AUX DATA SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO

SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS, NOCOUNT ON
GO
SET DATEFORMAT YMD
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION

PRINT(N'Update rows in [dbo].[CHECK_CATALOG_RESULT]')
UPDATE [dbo].[CHECK_CATALOG_RESULT] SET [CHECK_RESULT]='OOC-Baseline Period Expired', [SEVERITY_CD]='CRIT1' WHERE [CHECK_CATALOG_RESULT_ID] = 4998
UPDATE [dbo].[CHECK_CATALOG_RESULT] SET [CHECK_RESULT]='OOC-Missing Fuel Flow to Load Test' WHERE [CHECK_CATALOG_RESULT_ID] = 4999
UPDATE [dbo].[CHECK_CATALOG_RESULT] SET [CHECK_RESULT]='OOC-Baseline Period Expired', [SEVERITY_CD]='CRIT1' WHERE [CHECK_CATALOG_RESULT_ID] = 5036
UPDATE [dbo].[CHECK_CATALOG_RESULT] SET [CHECK_RESULT]='OOC-Missing Fuel Flow to Load Test' WHERE [CHECK_CATALOG_RESULT_ID] = 5037
PRINT(N'Operation applied to 4 rows out of 4')

PRINT(N'Update row in [dbo].[SYSTEM_PARAMETER]')
UPDATE [dbo].[SYSTEM_PARAMETER] SET [PARAM_VALUE3]=N'CAMD at CAMDForms@epa.gov' WHERE [SYS_PARAM_ID] = 4 AND (sys_param_id not in (1, 2, 5))

PRINT(N'Update rows in [dbo].[RESPONSE_CATALOG]')
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='Although Unit ID [Unit ID] is a [program] affected unit, monitoring method(s) for [method] have not been reported for the unit, for a common stack or pipe linked to the unit, or for all multiple stacks or pipes linked to the unit for the entire evaluation period.  If you believe that this error is incorrect, and has been caused by an inaccurate date in the Unit Program record, please contact ECMPS Support at ecmps-support@camdsupport.com.' WHERE [RESPONSE_CATALOG_ID] = 40122
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='The [testtype] status for [key] could not be determined because a fuel-flow-to-load baseline for MonitoringSystemID [ID] was not reported, and the baseline deadline has expired.' WHERE [RESPONSE_CATALOG_ID] = 41783
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='The [testtype] status for [key] could not be determined, because a prior ''PASSED'', ''EXC168H'' or ''FEW168H'' fuel-flow-to-load test for MonitoringSystemID [ID] was missing for [missingff2l].' WHERE [RESPONSE_CATALOG_ID] = 41784
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='You reported a monitoring methodology for [key], but the BeginDate is not consistent with the dates in the Unit Program records (or Unit Stack Configuration records) associated with this location.  If you believe that this error is incorrect, and has been caused by an inaccurate date in the Unit Program record, please contact ECMPS Support at ecmps-support@camdsupport.com.' WHERE [RESPONSE_CATALOG_ID] = 41815
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='You reported a monitoring methodology for [key] with an End Date that is not consistent with the End Date in the Unit Program records (or Unit Stack Configuration records) associated with this location.  If you believe that this error is incorrect, and has been caused by an inaccurate date in the Unit Program record, please contact ECMPS Support at ecmps-support@camdsupport.com.' WHERE [RESPONSE_CATALOG_ID] = 41969
UPDATE [dbo].[RESPONSE_CATALOG] SET [RESPONSE_CATALOG_DESCRIPTION]='Although Unit ID [Unit ID] is a [program] affected unit, monitoring method(s) for [method] have not been reported for the unit, or for a common or multiple stack linked to the unit for the entire evaluation period.  If you believe that this error is incorrect, and has been caused by an inaccurate date in the Unit Program record, please contact ECMPS Support at ecmps-support@camdsupport.com.' WHERE [RESPONSE_CATALOG_ID] = 42304
PRINT(N'Operation applied to 6 rows out of 6')

PRINT(N'Update rows in [dbo].[CHECK_PARAMETER_CODE]')
UPDATE [dbo].[CHECK_PARAMETER_CODE] SET [CHECK_PARAM_ID_NAME]='FF2L_Problem_TestNum_List', [CHECK_PARAM_ID_DESCRIPTION]='The TestNumber list of invalid Fuel-Flow-to-Load Tests in the Appendix D Status analysis.', [DISPLAY_NAME]='FF2L Problem TestNum List' WHERE [CHECK_PARAM_ID] = 3098
UPDATE [dbo].[CHECK_PARAMETER_CODE] SET [CHECK_PARAM_ID_NAME]='FF2L_Problem_Quarter_List', [CHECK_PARAM_ID_DESCRIPTION]='The year and quarter list for which  fuel-flow-to-load tests are missing in the Appendix D status analysis.', [DISPLAY_NAME]='FF2L Problem Quarter List' WHERE [CHECK_PARAM_ID] = 3099
PRINT(N'Operation applied to 2 rows out of 2')

PRINT(N'Update rows in [dbo].[CHECK_CATALOG]')
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil Times New Roman;}{\f1\fnil\fcharset0 Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 For the linearity check:\par
\par
\pard\li675 If the ComponentID is null,\par
\pard\li1350 set Linearity Component Valid to false, and return result A.\par
\par
\pard\li675 Otherwise\par
\pard\li1350 If the TestTypeCode is equal to "LINE",\par
\pard\li2025 If the ComponentTypeCode of the associated component is equal to "NOX", "SO2", "CO2", \f1  or \f0 "O2",\par
\pard\li2700 set LinearityTestType to "linearity check".\par
set Linearity Component Valid to true.\par
\par
\pard\li2025 Otherwise,\par
\pard\li2700 set Linearity Component Valid to false, and return result B.\par
\pard\li1350\f1\par
else if\f0  the TestTypeCode is equal to "\f1 HG\f0 LINE",\par
\pard\li2025 If the ComponentTypeCode of the associated component is equal to "\f1 HG\f0 ", \par
\pard\li2700 set LinearityTestType to "\f1 Hg \f0 linearity check".\par
set Linearity Component Valid to true.\par
\pard\li1350\par
\pard\li2025 Otherwise,\par
\pard\li2700 set Linearity Component Valid to false, and return result B.\par
\pard\li1350\par
\par
else if the TestTypeCode is equal to "HGSI\f1 3\f0 ",\par
\pard\li2025 If the ComponentTypeCode of the associated component is equal to "HG",\par
\pard\li2700 set LinearityTestType to "three-point system integrity check".\par
set Linearity Component Valid to true.\par
\par
\pard\li2025 Otherwise,\par
\pard\li2700 set Linearity Component Valid to false, and return result C.\par
\pard\li1350\par
\par
\f1 If  Linearity Component Valid is true  AND  \f0 TestTypeCode\f1  is equal to \f0 "LINE",\f1  \f0 "\f1 HG\f0 LINE"\f1  or \f0 "HGSI\f1 3\f0 "\f1 ,\par
\par
\pard\li2025 Locate System Component Records where:\par
\par
\pard\li2700 1) ComponentID equals the linearity check ComponentID.\par
2) BeginDate\\BeginHour is on or before the linearity check BeginDate\\BeginHour.\par
3) EndDate\\EndHour is null OR is on or after the linearity check BeginDate\\BeginHour.\par
4) BeginDate\\BeginHour is on or before the linearity check EndDate\\EndHour.\par
5) EndDate\\EndHour is null OR is on or after the linearity check EndDate\\EndHour.\par
\pard\li2025\par
If  System Component Records NOT found,\par
\par
\pard\li2700 Locate the earliest record in System Component Records based on SystemBeginDate\\SystemBeginHour where ComponentID equals the linearity check ComponentID.\par
\par
If  System Component Records is NOT found  OR  SystemBeginDate\\SystemBeginHour is on or before the linearity check EndDate\\EndHour,\par
\par
\pard\li3375\f0 set Linearity Component Valid to false, and return result \f1 D\f0 .\f1\par
\pard\li675\par
\pard\f0\par
\pard\li675 If Linearity Component is invalid, do not perform checks for the Linearity Summary (Pass 1), Linearity Injection, and Linearity Summary (Pass 2) categories.  Set the calculated values in the associated Linearity Summary records to null.\par
\pard\f1\par
}
' WHERE [CHECK_CATALOG_ID] = 207
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil Times New Roman;}{\f1\fnil\fcharset0 Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 For a Monitoring Default record with a valid ParameterCode:\par
\par
\pard\li675 Set Default Fuel Code Valid to true.\par
\par
If the FuelCode is null,\par
\pard\li1350 set Default Fuel Code Valid to false, and return result A.\par
\par
\pard\li675 Otherwise,\par
\par
\pard\li1350 Locate FuelCode in the FuelCode Lookup Table.\par
\par
If not found,\par
\pard\li2025 set Default Fuel Code Valid to false, and return result B.\par
\par
\pard\li1350 Otherwise,\par
\par
\pard\li2025 Set Default Unit Fuel to the Unit Fuel in the FuelCode lookup table record.\par
\par
If the ParameterCode is equal to "SO2R", "CO2R", or "NOXR", and the DefaultPurposeCode is not equal to "F23",\par
\par
\pard\li2700 If the FuelGroup in the FuelCode lookup table record is not equal to "GAS", "OIL" or\par
"MIX",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2025 If the ParameterCode is equal to "SO2R", the DefaultPurposeCode is equal to "F23", and the DefaultSourceCode is not equal to "APP",\par
\par
\pard\li2700 If the FuelCode is not equal to "NNG", "PNG", or "OGS",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2025 If the ParameterCode begins with "O2" or is equal to "CO2N", "CO2X", "H2ON", \f1 or  \f0 "H2OX", \par
\par
\pard\li2700 If the FuelCode is not equal to "NFS",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2025 If the ParameterCode is equal to "H2O", and the DefaultSourceCode is not equal to "APP",\par
\par
\pard\li2700 If the FuelCode is not equal to "NNG", "PNG", "CRF", or "W", or the FuelGroup in the FuelCode lookup table record is not equal to "COAL",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2700\f1 If \f0 the FuelCode is equal to "\f1 C\f0 ", \f1 and the EndDate is null or on or after 1/1/2022,\par
\pard\li3375\f0 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2025 If the ParameterCode is equal to "MNGF",\par
\par
\pard\li2700 If the FuelGroup in the FuelCode lookup table record is not equal to "GAS" or MIX",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\pard\li2025 If the ParameterCode is equal to "MNOF",\par
\par
\pard\li2700 If the FuelGroup in the FuelCode lookup table record is not equal to "OIL" or MIX",\par
\pard\li3375 set Default Fuel Code Valid to false, and return result C.\par
\par
\par
\par
\par
\par
\f1\par
}
' WHERE [CHECK_CATALOG_ID] = 244
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil\fcharset0 Times New Roman;}{\f1\fnil Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 Set \b\i FF2LAccuracyBeginYearQuarter\b0\i0  = null.\par
Set \b\i FF2LAccuracyEndYearQuarter\b0\i0  = null.\par
Set \b\i FF2LProblemTestNumList\b0\i0  = null.\par
Set \b\i FF2LProblemQuarterList\b0\i0  = null.\par
\par
\par
if (\b\i FF2LAccuracyEligible\b0\i0  == true)\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult is equal to \f0 "FAILED"\f1  and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\par
if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Fuel Flow to Load Test Failed".\par
exit check.\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult is \f0 NULL \f1 and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\pard\li1350\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\pard\li1350\par
Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Fuel Flow to Load Test Has Critical Errors".\par
exit check.\par
\pard\li2025\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the\f0  QANeedsEvaluation flag \f1 is \f0 equal to "Y" \f1 and the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the quarter is subsequent to the quarter of the later of the \b\i PriorAccuracyRecord\b0\i0 .EndDate and the \b\i PriorAccuracyRecord\b0\i0 .ReinstallationDate.\par
\pard\li2025\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "Fuel Flow to Load Test Has Not Yet Been Evaluated".\par
exit check.\par
\pard\li675\tab\par
\par
Set \b\i FF2LAccuracyBeginYearQuarter\b0\i0  = the quarter after the quarter of the \b\i FF2LAccuracyCheckDate.\b0\i0\par
Set \b\i FF2LAccuracyEndYearQuarter\b0\i0  = \f1 the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0 .\par
\par
\par
Set \i PriorAccuracyDateHour\i0  = \b\i FF2LAccuracyCheckDate\b0\i0 .\par
Set \i PriorAccuracyQuarter\i0  = the quarter of the \i PriorAccuracyDate\i0 .\par
Set \i CurrentOperatingQuarter\i0  = the quarter of the \b\i CurrentOperatingDateHour\b0\i0 .\par
\par
\par
if   ( \i CurrentOperatingQuarter\i0  is after the quarter subsequent to the \i PriorAccuracyQuarter\i0  )\par
\par
\pard\li1350 Locate the earliest \i FF2LBaselineDataRecord\i0  in \b\i FF2LBaseline\f1 RecordsByLocationForQAStatus\b0\i0\f0  where:\par
\par
\pard\li2025 1) System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) EndDateHour is after the \i PriorAccuracyDateHour\i0 .\par
3) EndDateHour is before the earlier of the \b\i CurrentOperatingDateHour\b0\i0 , AND the 5th quarter after the \i PriorAccuracyQuarter\i0 .\par
\pard\li1350\par
\par
if  ( \i FF2LBaselineDataRecord\i0  is found )\par
\par
\pard\li2025 if   ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is before the \i CurrentOperatingQuarter\i0  )\par
\par
\pard\li2700 Set \i MissingQuarterList\i0  = "".\par
Set \i BadResultQuarterList\i0  = "".\par
Set \i BadResultTestList\i0  = "".\par
\par
for each \i TargetQuarter\i0  from the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter to the quarter before the \i CurrentOperatingQuarter\i0 .\par
\par
\pard\li3375 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4050 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li3375\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4050 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li3375\par
else\f1\par
\par
\pard\li4050 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li4725 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4050\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4050\par
else\par
\par
\pard\li4725\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400 Set \i OpHourCount\i0  = null.\par
\pard\li3375\par
\par
\f1 Locate \f0 a \i FF2LTestRecord \i0\f1 in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4050 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "PASSED", "EXC168H" or "FEW168H".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li3375\par
if  ( \i FF2LTestRecord \i0  is NOT found )\par
\par
\pard\li4050 if  ( ( \i OpHourCount\i0  is null )  OR  ( \i OpHourCount\i0  is greater than 0 ) )  AND  ( \i TargetQuarter is NOT equal to PriorAccuracyQuarter\i0  )\par
\pard\li4725 Append \i TargetQuarter\i0  to \i MissingQuarterList\i0 .\par
\pard\li3375\par
else\par
\pard\li4050\par
if  ( \i OpHourCount\i0  is NOT null )\par
\par
\pard\li4725 if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "PASSED" or "EXC168H" ) AND ( \i OpHourCount\i0  is less than 168 )\par
\par
\pard\li5400 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li4050\par
\pard\li4725 else if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "FEW168H" ) AND ( \i OpHourCount\i0  is greater than or equal to 168 )\par
\par
\pard\li5400 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li2700\par
\par
if  ( \i MissingQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i MissingQuarterList\i0 .\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Missing Fuel Flow to Load Test".\par
\pard\li2700\par
else if ( \i BadResultQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i BadResultQuarterList\i0 .\par
Set \b\i FF2LProblemTestNumList\b0\i0  = \i BadResultTestList\i0 .\par
Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Invalid Fuel Flow to Load Test Result".\par
\pard\li2700\par
else\par
\pard\li3375 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is after the quarter subsequent to the \i PriorAccuracyQuarter\i0  )\par
\par
\pard\li4050 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \i PriorAccuracyQuarter\i0  AND before the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter.\par
\f1\par
\pard\li4725 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li5400 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4725\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li5400 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li6075 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li5400\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li5400\par
else\f1\par
\par
\pard\li6075 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6750 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6075\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6075\par
else\par
\par
\pard\li6750\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li7425 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li6750\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li7425 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6750\par
else\par
\par
\pard\li7425 Set \i OpHourCount\i0  = null.\par
\pard\li5400\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li6075 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li4050\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li4725 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li1350\par
else\par
\par
\pard\li2025 if  ( \b\i CurrentOperatingQuarter\b0\i0  is before the 5th quarter after the \i PriorAccuracyQuarter\i0  )\par
\pard\li2700\par
Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \i PriorAccuracyQuarter\i0  AND before the \i CurrentOperatingQuarter\i0 .\par
\f1\par
\pard\li3375 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4050 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li3375\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li4050 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4725 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4050\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4050\par
else\f1\par
\par
\pard\li4725 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075 Set \i OpHourCount\i0  = null.\par
\pard\li4050\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li4725 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li2700\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li3375 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li2025\par
else\par
\pard\li2700 Set \b\i CurrentAccuracy\f1 Status\b0\i0  \f0 = "OOC-Baseline Period Expired".\par
\pard\par
}
' WHERE [CHECK_CATALOG_ID] = 2287
UPDATE [dbo].[CHECK_CATALOG] SET [TECH_NOTE]='{\rtf1\ansi\ansicpg1252\deff0\deflang1033{\fonttbl{\f0\fnil\fcharset0 Times New Roman;}{\f1\fnil Times New Roman;}}
\viewkind4\uc1\pard\f0\fs20 Set \b\i FF2LPEIBeginYearQuarter\b0\i0  = null.\par
Set \b\i FF2LPEIEndYearQuarter\b0\i0  = null.\par
Set \b\i FF2LProblemTestnumList\b0\i0  = null.\par
Set \b\i FF2LProblemQuarterList\b0\i0  = null.\par
\par
\par
if (\b\i FF2LPEIEligible\b0\i0  == true)\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult\f0 Code\f1  is equal to \f0 "FAILED"\f1  and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\par
if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\pard\f1\par
\pard\li1350 Locate \f0 a \f1 record in \b\i QACertificationEventRecords\b0\i0  \f0 WHERE\f1\par
\pard\li675\par
\pard\li1350\f0 a) \f1 the \f0 Component\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0\f1 .\f0 Component\f1 ID \f0 AND\par
b) the QACertEventCode is equal to "410"\par
c) the RequiredTestCode is equal to "53"AND\par
d) the \f1 QACertEventDate/Hour is after the EndDate/Hour\f0  and of the located failed \b\i FF2L\f1 TestRecordsByLocationForQAStatu\f0 s\b0\i0  record.\f1\par
\f0 e) \f1 the QACertEventDate\f0 /Hour\f1  \f0 is \f1 prior to the \b\i\f0 CurrentOperatingDate/Hour \b0\i0\f1\par
\pard\li675\par
\pard\li1350 if (\b\i QACertificationEventRecords\b0\i0  is\f0  not\f1  found)\par
\pard\li675\f0\par
\pard\li2025 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "OOC-Fuel Flow to Load Test Failed".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\pard\li1350\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the TestResult\f0 Code\f1  is \f0 NULL \f1 and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\pard\li1350\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "OOC-Fuel Flow to Load Test Has Critical Errors".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\par
\pard\li675\f1 Locate \f0 any \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where the \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID\f1  and the\f0  QANeedsEvaluation flag \f1 is \f0 equal to "Y" \f1 and the \f0 Year/Quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0  and the Year/Quarter is subsequent to the quarter of the \b\i PriorPEIRecord\b0\i0 .EndDate.\par
\pard\li2025\par
\pard\li675 if (\b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is found)\par
\par
\pard\li1350 Set \b\i FF2LProblemTestnumList\b0\i0  =\b\i  FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0 .TestNumber\par
Set \b\i CurrentPEI\f1 Status\b0\i0  \f0  = "Fuel Flow to Load Test Has Not Yet Been Evaluated".\par
Return result \b\i CurrentPEI\f1 Status\b0\i0\f0 .\par
\pard\li675\par
\par
Set \b\i FF2LPEIBeginYearQuarter\b0\i0  to the quarter after the quarter of the \b\i FF2LPEICheckDate\b0\i0 .\par
Set \b\i FF2LPEIEndYearQuarter\b0\i0  = \f1 the \f0 quarter is prior to the quarter of the \b\i CurrentOperatingDate\b0\i0 .\par
\par
\par
Set \i CurrentOperatingQuarter\i0  = the quarter of the \b\i CurrentOperatingDateHour\b0\i0 .\par
\par
\par
if   ( \i CurrentOperatingQuarter\i0  is after the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li1350 Locate the earliest \i FF2LBaselineDataRecord\i0  in \b\i FF2LBaseline\f1 RecordsByLocationForQAStatus\b0\i0\f0  where:\par
\par
\pard\li2025 1) System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) EndDateHour is after the \b\i PriorPEIRecord\b0\i0 .EndDateHour.\par
3) EndDateHour is before the earlier of the \b\i CurrentOperatingDateHour\b0\i0 , AND the 5th quarter after the \b\i PriorPEIRecord\b0\i0 .EndDateHour.\par
\pard\li1350\par
\par
if  ( \i FF2LBaselineDataRecord\i0  is found )\par
\par
\pard\li2025 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is before the \i CurrentOperatingQuarter\i0  )\par
\par
\pard\li2700 Set \i MissingQuarterList\i0  = "".\par
Set \i BadResultQuarterList\i0  = "".\par
Set \i BadResultTestList\i0  = "".\par
\par
for each \i TargetQuarter\i0  from the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter to the quarter before the \i CurrentOperatingQuarter\i0 .\par
\par
\pard\li3375 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4050 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li3375\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4050 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li3375\par
else\f1\par
\par
\pard\li4050 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li4725 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4050\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4050\par
else\par
\par
\pard\li4725\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400 Set \i OpHourCount\i0  = null.\par
\pard\li3375\par
\par
\f1 Locate \f0 a \i FF2LTestRecord \i0\f1 in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4050 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "PASSED", "EXC168H" or "FEW168H".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li3375\par
if  ( \i FF2LTestRecord \i0  is NOT found )\par
\par
\pard\li4050 if  ( ( \i OpHourCount\i0  is null )  OR  ( \i OpHourCount\i0  is greater than 0 ) )  AND  ( \i TargetQuarter is NOT equal to \i0 quarter of the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\pard\li4725 Append \i TargetQuarter\i0  to \i MissingQuarterList\i0 .\par
\pard\li3375\par
else\par
\pard\li4050\par
if  ( \i OpHourCount\i0  is NOT null )\par
\par
\pard\li4725 if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "PASSED" or "EXC168H" ) AND ( \i OpHourCount\i0  is less than 168 )\par
\par
\pard\li5400 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li4050\par
\pard\li4725 else if  ( \i FF2LTestRecord\i0 .\f1 TestResult\f0 Code\f1  \f0 is equal to "FEW168H" ) AND ( \i OpHourCount\i0  is greater than or equal to 168 )\par
\par
\pard\li5400 Append \i TargetQuarter\i0  to \i BadResultQuarterList\i0 .\par
Append \i FF2LTestRecord\i0 .\f1 Test\f0 Number\f1  \f0 to \i BadResultTestList\i0 .\par
\pard\li2700\par
\par
if  ( \i MissingQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i MissingQuarterList\i0 .\par
Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Missing Fuel Flow to Load Test".\par
\pard\li2700\par
else if ( \i BadResultQuarterList\i0  NOT equal to "" )\par
\par
\pard\li3375 Set \b\i FF2LProblemQuarterList\b0\i0  = \i BadResultQuarterList\i0 .\par
Set \b\i FF2LProblemTestnumList\b0\i0  = \i BadResultTestList\i0 .\par
Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Invalid Fuel Flow to Load Test Result".\par
\pard\li2700\par
else\par
\pard\li3375 if  ( \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter is after the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li4050 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour AND before the \i FF2LBaselineDataRecord\i0 .CalendarYear/Quarter.\par
\f1\par
\pard\li4725 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li5400 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li4725\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li5400 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li6075 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li5400\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li5400\par
else\f1\par
\par
\pard\li6075 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6750 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li6075\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li6750 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6075\par
else\par
\par
\pard\li6750\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li7425 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li6750\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li7425 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li6750\par
else\par
\par
\pard\li7425 Set \i OpHourCount\i0  = null.\par
\pard\li5400\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\pard\li6075\par
Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li4050\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li4725 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li1350\par
else\par
\par
\pard\li2025 if  ( \b\i CurrentOperatingQuarter\b0\i0  is before the 5th quarter after the \b\i PriorPEIRecord\b0\i0 .EndDateHour )\par
\par
\pard\li2700 Set \b\i FF2LProblemQuarterList\b0\i0  = "".\par
\par
for each \i TargetQuarter \i0 from the quarter subsequent to the \b\i PriorPEIRecord\b0\i0 .EndDateHour AND before the \i CurrentOperatingQuarter\i0 .\par
\f1\par
\pard\li3375 Locate \f0 a \f1 record in \b\i\f0 FF2L\f1 TestRecordsByLocationForQAStatus \b0\i0 for the location where\f0 :\par
\par
\pard\li4050 1)\f1  \f0 System\f1 ID is equal to the \b\i\f0 FuelFlowComponentRecordToCheck\b0\i0 .SystemID.\par
2) \f1 TestResult\f0 Code\f1  is \f0 equal to "INPROG".\par
3) CalendarYear/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li3375\par
if  ( \b\i FF2L\f1 TestRecordsByLocationForQAStatus\b0\i0\f0  is NOT found )\par
\par
\pard\li4050 Locate \i SystemOperatingSuppDataRecord\i0  in \b\i SystemOperatingSuppDataRecordsByLocation\b0\i0  where:\par
\par
\pard\li4725 1) SystemId is equal to \b\i FuelFlowComponentRecordToCheck\b0\i0 .SystemId.\par
2) OpSuppDataTypeCode is equal to "OP".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4050\par
if  ( \i SystemOperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li4725 Set \i OpHourCount\i0  = \i SystemOperatingSuppDataRecord\i0 .Hours.\par
\pard\li4050\par
else\f1\par
\par
\pard\li4725 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li5400 1) FuelCode is equal to \b\i\f1 CurrentFuelFlowRecord.\b0\i0 FuelCode\f0 .\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0  .\par
\pard\li4725\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )\par
\par
\pard\li5400 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li4725\par
else\par
\par
\pard\li5400\f1 Locate \i\f0 OperatingSuppDataRecord\i0  \f1 in \b\i OperatingSuppDataRecordsbyLocation\b0\i0  where\f0 :\par
\par
\pard\li6075 1) FuelCode is null.\par
2)\f1  OpTypeCode is equal to \f0 "\f1 OPHOURS\f0 ".\par
3) Year/Quarter is equal to \i TargetQuarter\i0 .\par
\pard\li5400\par
if  ( \i OperatingSuppDataRecord\i0  is NOT null )  AND  ( \i OperatingSuppDataRecord\i0 .OpValue is equal to 0 )\par
\par
\pard\li6075 Set \i OpHourCount\i0  = \i OperatingSuppDataRecord\i0 .OpValue.\par
\pard\li5400\par
else\par
\par
\pard\li6075 Set \i OpHourCount\i0  = null.\par
\pard\li4050\par
if  ( ( \i OpHourCount\i0  is null )  AND  ( \i TargetQuarter \i0 is on or after the quarter of \b\i CurrentFuelFlowRecord\b0\i0 .SystemBeginDate ) )  OR   ( ( \i OpHourCount\i0  is NOT null )  AND  ( \i OpHourCount\i0  is greater than 0 ) )\par
\par
\pard\li4725 Append \i TargetQuarter\i0  to \b\i FF2LProblemQuarterList\b0\i0 .\par
\pard\li2700\par
if  ( \b\i FF2LProblemQuarterList\b0\i0  is NOT equal to "" )\par
\par
\pard\li3375 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Inprogress Fuel Flow to Load Test Required".\par
\pard\li2025\par
else\par
\pard\li2700 Set \b\i CurrentPEI\f1 Status\b0\i0\f0  = "OOC-Baseline Period Expired".\par
\pard\par
}
' WHERE [CHECK_CATALOG_ID] = 2294
PRINT(N'Operation applied to 4 rows out of 4')

PRINT(N'Add rows to [dbo].[RESPONSE_CATALOG]')
SET IDENTITY_INSERT [dbo].[RESPONSE_CATALOG] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42452)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42452, 'The [TESTTYPE] status for [KEY] could not be determined because expected "INPROG" Fuel-Flow-To-Load Test(s) for MonitoringSystemID [ID] are missing in quarter(s) [MISSINGFF2L]. ', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42453)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42453, 'The [TESTTYPE] status for [KEY] could not be determined because of Fuel-Flow-To-Load Test TestResult disagreement with Operating Hour Count for MonitoringSystemID [ID] and TestNumber(s) [FF2LTESTNUM].', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42454)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42454, 'The [testtype] status for [key] could not be determined because a fuel-flow-to-load baseline for MonitoringSystemID [ID] was not reported, and the baseline deadline has expired.  An invalid prior [testtype] with TestNumber [invtestnum] was ignored.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42455)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42455, 'The [TESTTYPE] status for [KEY] could not be determined because expected "INPROG" Fuel-Flow-To-Load Test(s) for MonitoringSystemID [ID] are missing in quarter(s) [MISSINGFF2L].   An invalid prior [testtype] with TestNumber [invtestnum] was ignored.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42456)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42456, 'The [TESTTYPE] status for [KEY] could not be determined because of Fuel-Flow-To-Load Test TestResult disagreement with Operating Hour Count for MonitoringSystemID [ID] and TestNumber(s) [FF2LTESTNUM].  An invalid prior [testtype] with TestNumber [invtestnum] was ignored.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42457)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42457, 'The [testtype] status for [key] could not be determined, because a prior ''PASSED'', ''EXC168H'' or ''FEW168H'' fuel-flow-to-load test for MonitoringSystemID [ID] was missing for [missingff2l].  An invalid prior [testtype] with TestNumber [invtestnum] was ignored.', 'CHECK', NULL, NULL)
IF NOT EXISTS( SELECT 1 FROM [dbo].[RESPONSE_CATALOG] WHERE [RESPONSE_CATALOG_ID] = 42458)
	INSERT INTO [dbo].[RESPONSE_CATALOG] ([RESPONSE_CATALOG_ID], [RESPONSE_CATALOG_DESCRIPTION], [RESPONSE_TYPE_CD], [RESPONSE_CATALOG_HEADER], [SEVERITY_CD]) VALUES (42458, 'The begin and end hour range for this test did not occur within an active period for the associated component and did not occur during the certification period.', 'CHECK', NULL, NULL)
SET IDENTITY_INSERT [dbo].[RESPONSE_CATALOG] OFF
PRINT(N'Operation applied to 7 rows out of 7')

PRINT(N'Add rows to [dbo].[CHECK_CATALOG_PARAMETER]')
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_PARAMETER] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_PARAMETER] WHERE [CHECK_CATALOG_PARAM_ID] = 16608)
	INSERT INTO [dbo].[CHECK_CATALOG_PARAMETER] ([CHECK_CATALOG_PARAM_ID], [CHECK_CATALOG_ID], [CHECK_PARAM_ID], [CHECK_PARAM_USAGE_CD]) VALUES (16608, 2287, 3442, 'REQ')
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_PARAMETER] WHERE [CHECK_CATALOG_PARAM_ID] = 16609)
	INSERT INTO [dbo].[CHECK_CATALOG_PARAMETER] ([CHECK_CATALOG_PARAM_ID], [CHECK_CATALOG_ID], [CHECK_PARAM_ID], [CHECK_PARAM_USAGE_CD]) VALUES (16609, 2294, 3442, 'REQ')
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_PARAMETER] WHERE [CHECK_CATALOG_PARAM_ID] = 16610)
	INSERT INTO [dbo].[CHECK_CATALOG_PARAMETER] ([CHECK_CATALOG_PARAM_ID], [CHECK_CATALOG_ID], [CHECK_PARAM_ID], [CHECK_PARAM_USAGE_CD]) VALUES (16610, 207, 459, 'REQ')
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_PARAMETER] OFF
PRINT(N'Operation applied to 3 rows out of 3')

PRINT(N'Add rows to [dbo].[CHECK_CATALOG_RESULT]')
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_RESULT] ON
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7079)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7079, 2294, 'OOC-Inprogress Fuel Flow to Load Test Required', 'CRIT1', 42452, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7080)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7080, 2294, 'OOC-Invalid Fuel Flow to Load Test Result', 'CRIT1', 42453, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7081)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7081, 2288, 'OOC-Inprogress Fuel Flow to Load Test Required', 'CRIT1', 42452, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7082)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7082, 2288, 'OOC-Invalid Fuel Flow to Load Test Result', 'CRIT1', 42453, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7084)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7084, 2288, 'OOC-Baseline Period Expired*', 'CRIT1', 42454, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7085)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7085, 2288, 'OOC-Inprogress Fuel Flow to Load Test Required*', 'CRIT1', 42455, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7086)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7086, 2288, 'OOC-Invalid Fuel Flow to Load Test Result*', 'CRIT1', 42456, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7087)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7087, 2288, 'OOC-Missing Fuel Flow to Load Test*', 'CRIT1', 42457, 1)
IF NOT EXISTS( SELECT 1 FROM [dbo].[CHECK_CATALOG_RESULT] WHERE [CHECK_CATALOG_RESULT_ID] = 7088)
	INSERT INTO [dbo].[CHECK_CATALOG_RESULT] ([CHECK_CATALOG_RESULT_ID], [CHECK_CATALOG_ID], [CHECK_RESULT], [SEVERITY_CD], [RESPONSE_CATALOG_ID], [ES_ALLOWED_IND]) VALUES (7088, 207, 'D', 'INFORM', 42458, 1)
SET IDENTITY_INSERT [dbo].[CHECK_CATALOG_RESULT] OFF
PRINT(N'Operation applied to 9 rows out of 9')
COMMIT TRANSACTION
GO

------------------------------------------------------
--	ECMPS_AUX DATA SQL (END)
------------------------------------------------------

------------------------------------------------------
--	ECMPS_AUX VERSION SQL (BEGIN)
------------------------------------------------------

USE ECMPS_AUX
GO

PRINT(N'Add row to [dbo].[ECMPS_VERSION_LOG]')
GO
UPDATE [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] SET [IS_CURRENT_FLG]='N' WHERE IsNull([IS_CURRENT_FLG],'X') <> 'N' AND [REVISION] <> '2022 Q1'
IF NOT EXISTS( SELECT [REVISION] FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] WHERE [REVISION]='2022 Q1' )
    INSERT INTO [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [DESCRIPTION], [EXPECTED_CODE_VERSION], [MP_XSD_VERSION], [QA_XSD_VERSION], [EM_XSD_VERSION], [RELEASE_DATE], [IS_CURRENT_FLG]) 
    VALUES (1, 20221, '2022 Q1', '2022 Q1 Release', '1.20221.0309.*', '1.2', '1.3', '1.7', '2022-03-09 00:00:00.000', 'Y')

PRINT(N'Update [ECMPS_VERSION_LOG] in ECMPS and ECMPS_WS')
GO
DELETE FROM [ECMPS].[Client].[ECMPS_VERSION_LOG]
DELETE FROM [ECMPS_WS].[Client].[ECMPS_VERSION_LOG]

INSERT INTO [ECMPS].[Client].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [IS_CURRENT_FLG]) 
	SELECT MAJOR, MINOR, REVISION, IS_CURRENT_FLG
	FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] evl
	WHERE NOT EXISTS ( SELECT REVISION FROM [ECMPS].[Client].[ECMPS_VERSION_LOG] WHERE REVISION=evl.REVISION )

INSERT INTO [ECMPS_WS].[Client].[ECMPS_VERSION_LOG] ([MAJOR], [MINOR], [REVISION], [IS_CURRENT_FLG]) 
	SELECT MAJOR, MINOR, REVISION, IS_CURRENT_FLG
	FROM [ECMPS_AUX].[dbo].[ECMPS_VERSION_LOG] evl
	WHERE NOT EXISTS ( SELECT REVISION FROM [ECMPS_WS].[Client].[ECMPS_VERSION_LOG] WHERE REVISION=evl.REVISION )

------------------------------------------------------
--	ECMPS_AUX VERSION SQL (END)
------------------------------------------------------

--
-- Make sure we know it is a shared DB
--
UPDATE ECMPS_AUX..SYSTEM_PARAMETER
SET PARAM_VALUE2='1'
WHERE SYS_PARAM_NAME='DB_SETTINGS'
  AND PARAM_NAME2='IsSharedDB'
  AND PARAM_VALUE2='0'
GO

-- End Message
PRINT 'Update script has ended.'
PRINT 'If you encountered errors, email ECMPS Technical Support at ecmps-support@camdsupport.com'
GO
SET NOEXEC OFF